require 'default:combat'

function GetBonusSpellDamageFromMobileMods(spellName,spellSource)
	local bonusDamage = 0
	if(spellSource:IsPlayer()) then
		if(spellName == "Ruin") then
			bonusDamage = GetCachedMobileModByName("RuinSpellDamagePlus",spellSource) or 0
		elseif(spellName == "ManaMissile") then
			bonusDamage = GetCachedMobileModByName("ManaMissileSpellDamagePlus",spellSource) or 0
		elseif(spellName == "Fireball") then
			bonusDamage = GetCachedMobileModByName("FireballSpellDamagePlus",spellSource) or 0
		elseif(spellName == "Frost") then
			bonusDamage = GetCachedMobileModByName("FrostSpellDamagePlus",spellSource) or 0
		elseif(spellName == "Meteor") then
			bonusDamage = GetCachedMobileModByName("MeteorSpellDamagePlus",spellSource) or 0
		elseif(spellName == "Lightning") then
			bonusDamage = GetCachedMobileModByName("LightningSpellDamagePlus",spellSource) or 0
		elseif(spellName == "Bombardment") then
			bonusDamage = GetCachedMobileModByName("BombardmentSpellDamagePlus",spellSource) or 0
		elseif(spellName == "Electricbolt") then
			bonusDamage = GetCachedMobileModByName("ElectricBoltSpellDamagePlus",spellSource) or 0
		elseif(spellName == "Poison") then
			bonusDamage = GetCachedMobileModByName("PoisonSpellDamagePlus",spellSource) or 0
		elseif(spellName == "Walloffire") then
			bonusDamage = GetCachedMobileModByName("WallOfFireSpellDamagePlus",spellSource) or 0
		elseif(spellName == "Earthquake") then
			bonusDamage = GetCachedMobileModByName("EarthquakeSpellDamagePlus",spellSource) or 0
		end
	end
	return bonusDamage
end

function ExecuteSpellHitActions(atTraget, spellName, spellSource, spLoc, damageModifier,scrollUsed)
	Verbose("Magic", "ExecuteSpellHitActions", atTarget, spellName, spellSource)
	local damageAmount = 0
	local bonusBaseDamage = GetBonusSpellDamageFromMobileMods(spellName,spellSource)
	local baseDam = SpellData.AllSpells[spellName] and SpellData.AllSpells[spellName].SpellPower or 0
	-- hack to make ruin damage based on distance
	if ( spellName == "Ruin" and atTarget:IsValid() ) then
		local distance = this:DistanceFrom(atTarget)
		if ( distance > 2 ) then
			-- alter the damage by the distance
			if ( distance  > 4 ) then
				baseDam = baseDam * 0.25
			else
				baseDam = baseDam * 0.50
			end
		end
	elseif(spellName == "Meteor" and spLoc) then
		local distance = atTarget:GetLoc():Distance2(spLoc)
		if ( distance > 1 ) then
			-- alter the damage by the distance
			if ( distance  > 3 ) then
				baseDam = baseDam * 0.50
			else
				baseDam = baseDam * 0.75
			end
		end
	end

	if( damageModifier ) then
		baseDam = math.floor(baseDam * damageModifier)
	end

	baseDam = baseDam + bonusBaseDamage

	local damInfo = {}
	damInfo.Damage = baseDam
	damInfo.Type = SpellData.AllSpells[spellName] and SpellData.AllSpells[spellName].DamageType or "MAGIC"
	damInfo.Source = this
	damInfo.Attacker = this
	damInfo.Victim = atTarget
	damInfo.SpellCircle = SpellData.AllSpells[spellName] and SpellData.AllSpells[spellName].Circle or 1
	damInfo.ScrollUsed = scrollUsed or false


	--DebugMessage("SourceTeam: " .. tostring(damInfo.Source:GetObjVar("MobileTeamType")) .. " VictimTeam: " .. tostring(damInfo.Victim:GetObjVar("MobileTeamType")) )
	-- If the spell is flagged NoMobFrienldyFire we make sure it doesn't
	-- hurt mobs with the same "MobileTeamType"
	if( 
		SpellData.AllSpells[spellName].NoMobFrienldyFire 
		and damInfo.Source:HasObjVar("MobileTeamType")
		and damInfo.Victim:HasObjVar("MobileTeamType")
		and damInfo.Source:GetObjVar("MobileTeamType") == damInfo.Victim:GetObjVar("MobileTeamType")
	) then
		return
	end

	CheckOnDamageSpellHitProcs(this, atTarget)
	CheckDestructionMobileEffect(this, atTarget, baseDam, spellName)
	ApplyDamageToTarget(damInfo)
	ApplySpellEffects(spellName, atTarget, spellSource)
end

BaseCheckOnDamageSpellHitProcs = CheckOnDamageSpellHitProcs
function CheckOnDamageSpellHitProcs( player, target )
	BaseCheckOnDamageSpellHitProcs(player,target)
	if(player:IsPlayer() and GetCachedMobileModByName("OnSpellHitLeechHealthPlus",player) > 0) then
        StartMobileEffect(player, "OnSpellHitLeechHealth",target)
    end	
	if(player:IsPlayer() and GetCachedMobileModByName("OnSpellHitLeechManaPlus",player) > 0) then
        StartMobileEffect(player, "OnSpellHitLeechMana",target)
    end	
	if(player:IsPlayer() and GetCachedMobileModByName("OnSpellHitLeechStaminaPlus",player) > 0) then
        StartMobileEffect(player, "OnSpellHitLeechStamina",target)
    end	
	if(player:IsPlayer() and GetCachedMobileModByName("OnSpellHitDrainHealthPlus",player) > 0) then
        StartMobileEffect(player, "OnSpellHitDrainHealth",target)
    end	
	if(player:IsPlayer() and GetCachedMobileModByName("OnSpellHitDrainManaPlus",player) > 0) then
        StartMobileEffect(player, "OnSpellHitDrainMana",target)
    end	
	if(player:IsPlayer() and GetCachedMobileModByName("OnSpellHitDrainStaminaPlus",player) > 0) then
        StartMobileEffect(player, "OnSpellHitDrainStamina",target)
    end    
end

BaseTryExecuteOnMeleeHit = TryExecuteOnMeleeHit
function TryExecuteOnMeleeHit( player, target )
	BaseTryExecuteOnMeleeHit(player,target)
	if(player:IsPlayer() and GetCachedMobileModByName("OnMeleeHitLeechHealth",player) > 0) then
		StartMobileEffect(player, "OnMeleeHitLeechHealth",target)
	end
	if(player:IsPlayer() and GetCachedMobileModByName("OnMeleeHitLeechStamina",player) > 0) then
		StartMobileEffect(player, "OnMeleeHitLeechHealth",target)
	end
	if(player:IsPlayer() and GetCachedMobileModByName("OnMeleeHitLeechMana",player) > 0) then
		StartMobileEffect(player, "OnSMeleeHitLeechHealth",target)
	end
	if(player:IsPlayer() and GetCachedMobileModByName("OnMeleeHitDrainHealth",player) > 0) then
		StartMobileEffect(player, "OnMeleeHitDrainHealth",target)
	end
	if(player:IsPlayer() and GetCachedMobileModByName("OnMeleeHitDrainStamina",player) > 0) then
		StartMobileEffect(player, "OnMeleeHitDrainHealth",target)
	end
	if(player:IsPlayer() and GetCachedMobileModByName("OnMeleeHitDrainMana",player) > 0) then
		StartMobileEffect(player, "OnSMeleeHitDrainHealth",target)
	end
end

baseApplyDamageToTarget = ApplyDamageToTarget

function ApplyDamageToTarget(damageInfo)

	-- override block
	-- either the mobiles can have a objvar in the template called DamageType
	-- or they can be set by using their weapon skill applied in the template intializer
	if not(this:IsPlayer()) then
		if(this:HasObjVar("DamageType")) then 
			damageInfo.Type = this:GetObjVar("DamageType") 
		else
			if(GetSkillLevel(this,"SlashingSkill") > 0) then damageInfo.Type = "Slashing" end
			if(GetSkillLevel(this,"BrawlingSkill") > 0) then damageInfo.Type = "Bashing" end
			if(GetSkillLevel(this,"PiercingSkill") > 0) then damageInfo.Type = "Piercing" end
			if(GetSkillLevel(this,"BashingSkill") > 0) then damageInfo.Type = "Bashing" end
			if(GetSkillLevel(this,"LancingSkill") > 0) then damageInfo.Type = "Piercing" end
			if(GetSkillLevel(this,"ArcherySkill") > 0) then damageInfo.Type = "Bow" end
		end
	end

	-- continue normal opperation
	baseApplyDamageToTarget(damageInfo)
end