-----------------------------------------------------------------------------
-- CORE
-----------------------------------------------------------------------------
-- Core Version 0.1
-----------------------------------------------------------------------------
-- CRAFTING RULES
-----------------------------------------------------------------------------
-- Skill Gaining (min - max)
-- clothing 0 - 40
-- padded armor 30 - 70
-- linen armor  30 - 70  
-- leather 40-80
-- hardened 40-80
-- misc 10-100
-----------------------------------------------------------------------------
-- MENU CATEGORY TABLE
-----------------------------------------------------------------------------
RecipeCategories.FabricationSkill = 
{
	{
		Name = "Resources",
		Subcategories = 
		{
			{"Cloth","Cloth","RoyalSilkFabric"},
			{"Leather","Leather","TannedLeather"},				
		},
	},	
	{
		Name = "Armor",
		Subcategories = 
		{
			{"Head",},
			{"Legs",},
			{"Torso",},
		},
	},
	{
		Name = "Clothing",
		Subcategories = 
		{
			{"Head",},
			{"Legs",},
			{"Torso",},				
			{"Cloak","Cloak","PlantFabric"},
		},
	},		
    {
		Name = "Items",
		Subcategories = 
		{
			{"Tools","Tools","Tools"},
			{"Horse","Pet Gear","PetArmor"},
			{"Containers","Containers","Storage"}
		},
	},
}

-----------------------------------------------------------------------------
-- RECIPE TABLE
-----------------------------------------------------------------------------
AllRecipes.FabricationSkill = 
{
	-------------------------------------------------------------------------
	-- MATERIALS
	-------------------------------------------------------------------------
	Cloth = 
	{
        MinLevelToCraft = -15,
        MaxLevelToGain = 15,
        DisplayName = "Cloth",
        CraftingTemplateFile = "resource_bolt_of_cloth",
        Description = "A fabric woven from wool. Can be used to make clothing and armor.",
        ItemType = "ResourceClass",
        Category = "Resources",
        Subcategory = "Cloth",
        NeedRecipe = true,
        CanSalvage = false,
        Resources = 
        {
            Cotton = 1,
        },
    },
	EnchantedCloth = 
	{
        MinLevelToCraft = 48,
        MaxLevelToGain = 50,
        DisplayName = "Enchanted Cloth",
        CraftingTemplateFile = "resource_bolt_of_cloth_enchanted",
        Description = "A enchanted fabric woven from wool. Can be used to make magical clothing and armor.",
        ItemType = "ResourceClass",
        Category = "Resources",
        Subcategory = "Cloth",
        NeedRecipe = true,
        CanSalvage = false,
        Resources = 
        {
            Cloth = 1,
            Essence = 10,
        },
    },    
	Leather = 
	{
		MinLevelToCraft = -5,
		MaxLevelToGain = 20,
		DisplayName = "Leather",
		CraftingTemplateFile = "resource_leather",
		Description = "A material made from animal hides. Can be used to make leather armor.",
		ItemType = "ResourceClass",
		Category = "Resources",
		Subcategory = "Leather",
		NeedRecipe = true,
		CanSalvage = false,
		Resources = 
		{
			LeatherHide = 1,
		},
	},
	EnchantedLeather = 
	{
		MinLevelToCraft = 53,
		MaxLevelToGain = 55,
		DisplayName = "Enchanted Leather",
		CraftingTemplateFile = "resource_leather_enchanted",
		Description = "A enchanted material made from animal hides. Can be used to make magical leather armor.",
		ItemType = "ResourceClass",
		Category = "Resources",
		Subcategory = "Leather",
		NeedRecipe = true,
		CanSalvage = false,
		Resources = 
		{
			LeatherHide = 1,
            Essence = 10,
		},
	},
	-------------------------------------------------------------------------
	-- CLOTHING
	-------------------------------------------------------------------------
	LongSleeveShirt = 
	{
		MinLevelToCraft = 0,
		MaxLevelToGain = 40,
		DisplayName = "Long Sleeve Shirt",
		Description = "A long sleeved shirt that offers no armor protection.",
		NeedRecipe = true,
		CanImprove = false,
		CraftingTemplateFile = "clothing_long_sleeve_shirt_chest",
		ItemType = "ArmorClass",
		Category = "Clothing",
		Subcategory = "Torso",
		EnableCraftOrder = true,
		Resources = 
		{	
			Cloth = 8,
		},
	},
	ShortSleeveShirt = 
	{
		MinLevelToCraft = 0,
		MaxLevelToGain = 40,
		DisplayName = "Short Sleeve Shirt",
		Description = "A short sleeved shirt that offers no armor protection.",
		NeedRecipe = true,
		CanImprove = false,
		CraftingTemplateFile = "clothing_short_sleeve_shirt_chest",
		ItemType = "ArmorClass",
		Category = "Clothing",
		Subcategory = "Torso",
		EnableCraftOrder = true,
		Resources = 
		{	
			Cloth = 6,
		},
	},
	Shorts = 
	{
		MinLevelToCraft = 0,
		MaxLevelToGain = 40,
		DisplayName = "Shorts",
		Description = "Simple shorts that offers no armor protection.",
		NeedRecipe = true,
		CanImprove = false,
		CraftingTemplateFile = "clothing_shorts_legs",
		ItemType = "ArmorClass",
		Category = "Clothing",
		Subcategory = "Legs",
		EnableCraftOrder = true,
		Resources = 
		{	
			Cloth = 6,
		},
	},
	Skirt = 
	{
		MinLevelToCraft = 0,
		MaxLevelToGain = 40,
		DisplayName = "Skirt",
		Description = "A skirt wearable by both men and women that offers no armor protection.",
		NeedRecipe = true,
		CanImprove = false,
		CraftingTemplateFile = "clothing_skirt_legs",
		ItemType = "ArmorClass",
		Category = "Clothing",
		Subcategory = "Legs",
		EnableCraftOrder = true,
		Resources = 
		{	
			Cloth = 6,
		},
	},
	Apron = 
	{
		MinLevelToCraft = 0,
		MaxLevelToGain = 40,
		DisplayName = "Apron",
		Description = "A basic apron that offers no armor protection. A must for culinary masters.",
		NeedRecipe = true,
		CanImprove = false,
		CraftingTemplateFile = "clothing_apron_chest",
		ItemType = "ArmorClass",
		Category = "Clothing",
		Subcategory = "Torso",
		EnableCraftOrder = true,
		Resources = 
		{	
			Cloth = 6,
		},
	},
	Cloak = 
	{
		MinLevelToCraft = 0,
		MaxLevelToGain = 40,
		DisplayName = "Cloak",
		Description = "A basic cloak that offers no armor protection. A must for adventurers.",
		NeedRecipe = true,
		CanImprove = false,
		CraftingTemplateFile = "clothing_chest_cloak_basic",
		ItemType = "ArmorClass",
		Category = "Clothing",
		Subcategory = "Cloak",
		EnableCraftOrder = true,
		Resources = 
		{	
			Cloth = 10,
		},
	},
	BlacksmithsTunic = 
	{
		MinLevelToCraft = 0,
		MaxLevelToGain = 40,
		DisplayName = "Blacksmith Tunic",
		Description = "A blacksmith tunic.",
		NeedRecipe = true,
		CanImprove = false,
		CraftingTemplateFile = "clothing_chest_blacksmith",
		ItemType = "ArmorClass",
		Category = "Clothing",
		Subcategory = "Torso",
		EnableCraftOrder = true,
		Resources = 
		{	
			Cloth = 8,
		},
	},
	-------------------------------------------------------------------------
	-- CLOTH ARMOR
	-------------------------------------------------------------------------
	Bandana = 
	{
		MinLevelToCraft = 0,
		MaxLevelToGain = 40,
		DisplayName = "Bandana",
		Description = "A bandana.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "clothing_bandana_helm",
		ItemType = "ArmorClass",
		Category = "Clothing",
		Subcategory = "Head",
		EnableCraftOrder = true,
		Resources = 
		{	
			Cloth = { Cloth = 6 },
			EnchantedCloth = {EnchantedCloth = 6, Essence = 5}
		},
	},
	BanditHood = 
	{
		MinLevelToCraft = 0,
		MaxLevelToGain = 40,
		DisplayName = "Bandit Hood",
		Description = "A bandit hood.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "clothing_bandit_hood_helm",
		ItemType = "ArmorClass",
		Category = "Clothing",
		Subcategory = "Head",
		EnableCraftOrder = true,
		Resources = 
		{	
			Cloth = { Cloth = 6 },
			EnchantedCloth = {EnchantedCloth = 6, Essence = 5}
		},
	},
	MageHat = 
	{
		MinLevelToCraft = 0,
		MaxLevelToGain = 40,
		DisplayName = "Mage Hat",
		Description = "To act like a mage, you need to look like a mage.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "clothing_mage_hat_helm",
		ItemType = "ArmorClass",
		Category = "Clothing",
		Subcategory = "Head",
		EnableCraftOrder = true,
		Resources = 
		{	
			Cloth = { Cloth = 6 },
			EnchantedCloth = {EnchantedCloth = 6, Essence = 5}
		},
	},
	PaddedHelm = 
	{
		MinLevelToCraft = 30,
		MaxLevelToGain = 70,
		DisplayName = "Padded Helm",
		Description = "A Padded Helm is a robe armor piece protecting a user's head.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "robe_padded_helm",
		ItemType = "ArmorClass",
		Category = "Armor",
		Subcategory = "Head",
		EnableCraftOrder = true,
		Resources = 
		{
			Cloth = { Cloth = 8 },
			EnchantedCloth = {EnchantedCloth = 8, Essence = 5}
		},
	},
	PaddedLegs = 
	{
		MinLevelToCraft = 30,
		MaxLevelToGain = 70,
		DisplayName = "Padded Legs",
		Description = "Padded Leggings are a robe armor piece protecting a user's lower body.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "robe_padded_leggings",
		ItemType = "ArmorClass",
		Category = "Armor",
		Subcategory = "Legs",
		EnableCraftOrder = true,
		Resources = 
		{
			Cloth = { Cloth = 12 },
			EnchantedCloth = {EnchantedCloth = 12, Essence = 5}
		},
	},
	PaddedChest = 
	{
		MinLevelToCraft = 30,
		MaxLevelToGain = 70,
		DisplayName = "Padded Chest",
		Description = "A Padded Chest is a robe armor piece protecting a user's upper body.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "robe_padded_tunic",
		ItemType = "ArmorClass",
		Category = "Armor",
		Subcategory = "Torso",
		EnableCraftOrder = true,
		Resources = 
		{
			Cloth = { Cloth = 16 },
			EnchantedCloth = {EnchantedCloth = 16, Essence = 5}
		},
	},
	LinenHelm = 
	{
		MinLevelToCraft = 30,
		MaxLevelToGain = 70,
		DisplayName = "Linen Helm",
		Description = "A Linen Helm is a robe armor piece protecting a user's head.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "robe_linen_helm",
		ItemType = "ArmorClass",
		Category = "Armor",
		Subcategory = "Head",
		EnableCraftOrder = true,
		Resources = 
		{
			Cloth = { Cloth = 8 },
			EnchantedCloth = {EnchantedCloth = 8, Essence = 5}
		},
	},
	LinenLegs = 
	{
		MinLevelToCraft = 30,
		MaxLevelToGain = 70,
		DisplayName = "Linen Legs",
		Description = "Linen Leggings are a robe armor piece protecting a user's lower body.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "robe_linen_leggings",
		ItemType = "ArmorClass",
		Category = "Armor",
		Subcategory = "Legs",
		EnableCraftOrder = true,
		Resources = 
		{
			Cloth = { Cloth = 12 },
			EnchantedCloth = {EnchantedCloth = 12, Essence = 5}
		},
	},
	LinenChest = 
	{
		MinLevelToCraft = 30,
		MaxLevelToGain = 70,
		DisplayName = "Linen Chest",
		Description = "A Linen Chest is a robe armor piece protecting a user's upper body.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "robe_linen_tunic",
		ItemType = "ArmorClass",
		Category = "Armor",
		Subcategory = "Torso",
		EnableCraftOrder = true,
		Resources = 
		{
			Cloth = { Cloth = 16 },
			EnchantedCloth = {EnchantedCloth = 16, Essence = 5}
		},
	},
	MageRobes = 
	{
		MinLevelToCraft = 30,
		MaxLevelToGain = 70,
		DisplayName = "Mage Robes",
		Description = "An elegant robe",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "robe_robe",
		ItemType = "ArmorClass",
		Category = "Armor",
		Subcategory = "Torso",
		EnableCraftOrder = true,
		Resources = 
		{	
			Cloth = { Cloth = 20 },
			EnchantedCloth = {EnchantedCloth = 20, Essence = 5}
		},
	},
	-------------------------------------------------------------------------
	-- LEATHER ARMOR
	-------------------------------------------------------------------------
	LeatherHelm = 
	{
		MinLevelToCraft = 40,
		MaxLevelToGain = 80,
		DisplayName = "Leather Helm",
		Description = "A Leather Helm is a light armor piece protecting a user's head.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "armor_leather_helm",
		ItemType = "ArmorClass",
		Category = "Armor",
		Subcategory = "Head",
		EnableCraftOrder = true,
		Resources = 
		{
			Leather = { Leather = 10 },
			EnchantedLeather = {EnchantedLeather = 10, Essence = 5}
		},
	},
	LeatherLegs = 
	{
		MinLevelToCraft = 40,
		MaxLevelToGain = 80,
		DisplayName = "Leather Legs",
		Description = "Leather Leggings are a light armor piece protecting a user's lower body.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "armor_leather_leggings",
		ItemType = "ArmorClass",
		Category = "Armor",
		Subcategory = "Legs",
		EnableCraftOrder = true,
		Resources = 
		{
			Leather = { Leather = 14 },
			EnchantedLeather = {EnchantedLeather = 14, Essence = 5}
		},
	},
	LeatherChest = 
	{
		MinLevelToCraft = 40,
		MaxLevelToGain = 80,
		DisplayName = "Leather Chest",
		Description = "A Leather Chest is a light armor piece protecting a user's upper body.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "armor_leather_chest",
		ItemType = "ArmorClass",
		Category = "Armor",
		Subcategory = "Torso",
		EnableCraftOrder = true,
		Resources = 
		{
			Leather = { Leather = 18 },
			EnchantedLeather = {EnchantedLeather = 18, Essence = 5}
		},
	},
	HardenedHood = 
	{
		MinLevelToCraft = 40,
		MaxLevelToGain = 80,
		DisplayName = "Hardened Helm",
		Description = "A Hardened Leather Helm is a light armor piece protecting a user's head.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "armor_hardened_helm",
		ItemType = "ArmorClass",
		Category = "Armor",
		Subcategory = "Head",
		EnableCraftOrder = true,
		Resources = 
		{
			Leather = { Leather = 10 },
			EnchantedLeather = {EnchantedLeather = 10, Essence = 5}
		},
	},
	HardenedLeggings = 
	{
		MinLevelToCraft = 40,
		MaxLevelToGain = 80,
		DisplayName = "Hardened Leggings",
		Description = "Leather Leggings are a light armor piece protecting a user's lower body.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "armor_hardened_leggings",
		ItemType = "ArmorClass",
		Category = "Armor",
		Subcategory = "Legs",
		EnableCraftOrder = true,
		Resources = 
		{
			Leather = { Leather = 14 },
			EnchantedLeather = {EnchantedLeather = 14, Essence = 5}
		},
	},
	HardenedChest = 
	{
		MinLevelToCraft = 40,
		MaxLevelToGain = 80,
		DisplayName = "Hardened Chest",
		Description = "A Leather Chest is a light armor piece protecting a user's upper body.",
		NeedRecipe = true,
		CanImprove = true,
		CraftingTemplateFile = "armor_hardened_chest",
		ItemType = "ArmorClass",
		Category = "Armor",
		Subcategory = "Torso",
		EnableCraftOrder = true,
		Resources = 
		{
			Leather = { Leather = 18 },
			EnchantedLeather = {EnchantedLeather = 18, Essence = 5}
		},
	},
	-------------------------------------------------------------------------
	-- LEATHER MISC
	-------------------------------------------------------------------------
	Saddle = 
	{
		MinLevelToCraft = 10,
		MaxLevelToGain = 20,
		DisplayName = "Leather Saddle",
		Description = "Can be equipped on a horse to turn it into a ridable mount statue.",
		NeedRecipe = true,
		CanImprove = false,
		CraftingTemplateFile = "saddle_packed",
		ItemType = "ArmorClass",
		Category = "Items",
		Subcategory = "Horse",
		EnableCraftOrder = true,
		Resources = 
		{
			Leather = 6,
		},
	},
	Saddlebags = 
	{
		MinLevelToCraft = 60,
		MaxLevelToGain = 70,
		DisplayName = "Leather Saddlebags",
		Description = "Can be equipped on a horse to provide additional storage.",
		NeedRecipe = true,
		CanImprove = false,
		CraftingTemplateFile = "saddlebags_packed",
		ItemType = "ArmorClass",
		Category = "Items",
		Subcategory = "Horse",
		EnableCraftOrder = false,
		Resources = 
		{
			Leather = 12,
		},
	},				
	Waterskin = 
	{
		MinLevelToCraft = 10,
		MaxLevelToGain = 35,
		DisplayName = "Waterskin",
		Description = "Can be filled with water for refreshment and cooking.",
		NeedRecipe = true,
		CanImprove = false,
		CraftingTemplateFile = "waterskin",
		ItemType = "ResourceClass",
		Category = "Items",
		Subcategory = "Tools",
		EnableCraftOrder = true,
		Resources = 
		{
			Leather = 1,
		},
	},
	Pouch = 
	{
		MinLevelToCraft = 10,
		MaxLevelToGain = 15,
		DisplayName = "Pouch",
		Description = "A small leather pouch.",
		NeedRecipe = true,
		CanImprove = false,
		CraftingTemplateFile = "pouch",
		Category = "Items",
		Subcategory = "Containers",
		EnableCraftOrder = true,
		Resources = 
		{
			Leather = 6,
		},
	},
}