-----------------------------------------------------------------------------
-- CORE
-----------------------------------------------------------------------------
-- Core Version 0.1
-----------------------------------------------------------------------------
-- CRAFTING RULES
-----------------------------------------------------------------------------
-- Skill Gaining (min - max)
-- Ranged -10 - 10
-- Shields 9 - 20
-- Containers 19 - 30 
-- Fences 29 - 40
-- Tables 39 - 50
-- Chairs 39 - 50
-- CraftStations 49-89
-- DeocrativeItems 25 - 55
-- Lighting 59 - 89
-- House Walls 40 - 100
-- House Foundations 40 - 100
-- House Blueprints 40 - 100
-----------------------------------------------------------------------------
-- MENU CATEGORY TABLE
-----------------------------------------------------------------------------
RecipeCategories.WoodsmithSkill = 
{
	{
		Name = "Resources",
		Subcategories = 
		{
            {"Wood","Wood","Wood"},
        },
	},	
	{
		Name = "Equipment",
		Subcategories = 
		{
			{"Ranged","Ranged","Ranged"},
			{"Shields","Shields","Shield"},
			{"Staves","Staves","Casting"},
			{"Wands","Wand","Casting"},			
		},
	},	
	{
		Name = "Furniture",
		Subcategories = 
		{
			{"Chairs","Chairs","Chairs"},
			{"Tables","Tables","Tables"},
			{"DecorativeItems" ,"Decorative Items"},
			{"Containers","Containers","Storage"},
			{"FencesWalls" ,"Fences","FencesWalls"},			
			{"Lighting" ,"Lighting", "Lighting"},
			{"CraftingStations" ,"Crafting Stations","CraftingStations"},			
		},
	},	
	{
		Name = "Housing",
		Subcategories = 
		{
			{"HouseWalls","Walls","CraftingStations"},
			{"HouseFoundation","Foundations","CraftingStations"},
			{"HouseBlueprints","Blueprints","CraftingStations"},			
		},
	},	
}

-----------------------------------------------------------------------------
-- RECIPE TABLE
-----------------------------------------------------------------------------
AllRecipes.WoodsmithSkill = 
{	
	-------------------------------------------------------------------------
	-- RESOURCES
	-------------------------------------------------------------------------
	Brick = {
		MinLevelToCraft = -15,
		MaxLevelToGain = 15,
		DisplayName = "Brick",
		CraftingTemplateFile = "resource_brick",
		Description = "Brick",
		ItemType = "ResourceClass",
		Category = "Resources",
		Subcategory = "Wood",
		NeedRecipe = true,
		CanSalvage = false,
		Resources = {
			Stone = 1,
		},
	},

	Boards = {
		MinLevelToCraft = -1,
		MaxLevelToGain = 20,
		DisplayName = "Wooden Boards",
		CraftingTemplateFile = "resource_boards",
		Description = "Wooden Boards",
		ItemType = "ResourceClass",
		Category = "Resources",
		Subcategory = "Wood",
		NeedRecipe = true,
		CanSalvage = false,
		Resources = {
			Wood = 1,
		},
	},
	EnchantedBoards = {
		MinLevelToCraft = 48,
		MaxLevelToGain = 50,
		DisplayName = "Enchanted Wooden Boards",
		CraftingTemplateFile = "resource_boards_enchanted",
		Description = "Enchanted Wooden Boards",
		ItemType = "ResourceClass",
		Category = "Resources",
		Subcategory = "Wood",
		NeedRecipe = true,
		CanSalvage = false,
		Resources = {
			Boards = 1,
			Essence = 10,
		},
	},
	-------------------------------------------------------------------------
	-- RANGED
	-------------------------------------------------------------------------
	Arrow = 
	{
		MinLevelToCraft = -10,
		MaxLevelToGain = 10,
		DisplayName = "Arrow",
		CraftingTemplateFile = "arrow",
		Description = "",
		NeedRecipe = true,
		CanImprove = false,
		Category = "Equipment",
		Subcategory = "Ranged",
		EnableCraftOrder = true,
		StackCount = 10,
		Resources = 
		{
			Boards = 1,
		},
	},	
	ShortBow = 
	{
		MinLevelToCraft = -10,
		MaxLevelToGain = 10,
		DisplayName = "Short Bow",
		CraftingTemplateFile = "weapon_shortbow",
		ItemType = "WeaponClass",
		Description = "A Short Bow. This is a apprentice weapon.",
		CanImprove = true,
		Category = "Equipment",
		Subcategory = "Ranged",
		NeedRecipe = true,
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = { Boards = 7 },
			EnchantedBoards = { EnchantedBoards= 7, Essence = 5, },		
		},
	},
	LongBow = 
	{
		MinLevelToCraft = -10,
		MaxLevelToGain = 10,
		DisplayName = "Long Bow",
		CraftingTemplateFile = "weapon_longbow",
		ItemType = "WeaponClass",
		Description = "A Long Bow. This is a rookie weapon.",
		CanImprove = true,
		Category = "Equipment",
		Subcategory = "Ranged",
		NeedRecipe = true,
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = { Boards = 7 },
			EnchantedBoards = { EnchantedBoards= 7, Essence = 5, },		
		},
	},
	WarBow = 
	{
		MinLevelToCraft = -10,
		MaxLevelToGain = 10,
		DisplayName = "War Bow",
		CraftingTemplateFile = "weapon_warbow",
		ItemType = "WeaponClass",
		Description = "A War Bow. This is a journeyman weapon.",
		CanImprove = true,
		Category = "Equipment",
		Subcategory = "Bows",
		NeedRecipe = true,
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = { Boards = 7 },
			EnchantedBoards = { EnchantedBoards= 7, Essence = 5, },		
		},
	},
	-------------------------------------------------------------------------
	-- SHIELDS
	-------------------------------------------------------------------------
	CurvedShield = 
	{
		MinLevelToCraft = 9,
		MaxLevelToGain = 20,
		DisplayName = "Curved Shield",
		CraftingTemplateFile = "shield_curved",
		Description = "",
		ItemType = "WeaponClass",
		NeedRecipe = true,
		CanImprove = true,
		Category = "Equipment",
		Subcategory = "Shields",
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = { Boards = 9 },
			EnchantedBoards = { EnchantedBoards= 9, Essence = 5, },		
		},
	},
	WoodenBucklerShield = 
	{
		MinLevelToCraft = 9,
		MaxLevelToGain = 20,
		DisplayName = "Wooden Buckler Shield",
		CraftingTemplateFile = "shield_wooden_buckler",
		Description = "",
		NeedRecipe = true,
		CanImprove = true,
		Category = "Equipment",
		Subcategory = "Shields",
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = { Boards = 9 },
			EnchantedBoards = { EnchantedBoards= 9, Essence = 5, },		
		},
	},
	SavageShield = 
	{
		MinLevelToCraft = 9,
		MaxLevelToGain = 20,
		DisplayName = "Savage Shield",
		CraftingTemplateFile = "shield_savage",
		Description = "",
		NeedRecipe = true,
		CanImprove = true,
		Category = "Equipment",
		Subcategory = "Shields",
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = { Boards = 9 },
			EnchantedBoards = { EnchantedBoards= 9, Essence = 5, },		
		},
	},
	-------------------------------------------------------------------------
	-- CONTAINERS
	-------------------------------------------------------------------------
	Crate = 
	{
		MinLevelToCraft = 19,
		MaxLevelToGain = 30,
		DisplayName = "Crate",
		Description = "A basic wooden crate used to store belongings.",
		NeedRecipe = true,
		CraftingTemplateFile = "crate_empty",
		Category = "Furniture",
		Subcategory = "Containers",
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = 15,
		},
	},
	Lockbox = 
	{
		MinLevelToCraft = 19,
		MaxLevelToGain = 30,
		DisplayName = "Lockbox",
		Description = "A lockable secure container used to store belongings.",
		NeedRecipe = true,
		CraftingTemplateFile = "lockbox",
		Category = "Furniture",
		Subcategory = "Containers",
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = 15,
		},
	},
	Dresser = 
	{
		MinLevelToCraft = 19,
		MaxLevelToGain = 30,
		DisplayName = "Dresser",
		Description = "[$3148]",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_dresser",
		Category = "Furniture",
		Subcategory = "Containers",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 25,
		},
	},	
	-------------------------------------------------------------------------
	-- FENCES
	-------------------------------------------------------------------------
	SmallFence = 
	{
		MinLevelToCraft = 29,
		MaxLevelToGain = 40,
		DisplayName = "Small Fence",
		Description = "[$3149]",
		NeedRecipe = true,
		CraftingTemplateFile = "fence_small",
		Category = "Furniture",
		Subcategory = "FencesWalls",
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = 8,
		},
	},
	Gate = 
	{
		MinLevelToCraft = 29,
		MaxLevelToGain = 40,
		DisplayName = "Gate",
		Description = "",
		NeedRecipe = true,
		CraftingTemplateFile = "fence_door",
		Category = "Furniture",
		Subcategory = "FencesWalls",
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = 12,
		},
	},
	-------------------------------------------------------------------------
	-- TABLES
	-------------------------------------------------------------------------
	DeskFancy = 
	{
		MinLevelToCraft = 39,
		MaxLevelToGain = 50,
		DisplayName = "Fancy Desk",
		ItemType = "FurnitureClass",
		Description = "[$3141]",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_desk_fancy",
		Category = "Furniture",
		Subcategory = "Tables",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 15,
		},
	},
	TableWooden = 
	{
		MinLevelToCraft = 39,
		MaxLevelToGain = 50,
		DisplayName = "Wooden Table",
		Description = "[$3143]",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_table_wooden",
		Category = "Furniture",
		Subcategory = "Tables",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 15,
		},
	},
	TableWoodenLarge = 
	{
		MinLevelToCraft = 39,
		MaxLevelToGain = 50,
		DisplayName = "Large Wooden Table",
		Description = "[$3144]",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_table_wooden_large",
		Category = "Furniture",
		Subcategory = "Tables",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 15,
		},
	},
	TableRound = 
	{
		MinLevelToCraft = 39,
		MaxLevelToGain = 50,
		DisplayName = "Round Table",
		Description = "[$3144]",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_table_round",
		Category = "Furniture",
		Subcategory = "Tables",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 15,
		},
	},
	TableInn = 
	{
		MinLevelToCraft = 39,
		MaxLevelToGain = 50,
		DisplayName = "Inn Table",
		Description = "[$3144]",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_table_inn",
		Category = "Furniture",
		Subcategory = "Tables",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 15,
		},
	},
	TableBlacksmith = 
	{
		MinLevelToCraft = 39,
		MaxLevelToGain = 50,
		DisplayName = "Blacksmith Table",
		Description = "A Blacksmith's Table",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_table_blacksmith",
		Category = "Furniture",
		Subcategory = "Tables",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 4,
			Iron = 15,
		},
	},	
	-------------------------------------------------------------------------
	-- CHAIRS
	-------------------------------------------------------------------------
	StoolWooden = 
	{
		MinLevelToCraft = 39,
		MaxLevelToGain = 50,
		DisplayName = "Wooden Stool",
		Description = "A small stool made of wood.",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_stool_wooden",
		Category = "Furniture",
		Subcategory = "Chairs",
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = 8,
		},
	},	
	BenchFancy = 
	{
		MinLevelToCraft = 39,
		MaxLevelToGain = 50,
		DisplayName = "Fancy Bench",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_bench_fancy",
		Description = "[$3133]",
		Category = "Furniture",
		Subcategory = "Chairs",
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = 8,
		},
	},
	ChairFancy = 
	{
		MinLevelToCraft = 39,
		MaxLevelToGain = 50,
		DisplayName = "Fancy Chair",
		Description = "[$3138]",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_chair_fancy",
		Category = "Furniture",
		Subcategory = "Chairs",
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = 8,
		},
	},
	ChairWooden = 
	{
		MinLevelToCraft = 39,
		MaxLevelToGain = 50,
		DisplayName = "Wooden Chair",
		Description = "[$3139]",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_chair_wooden",
		Category = "Furniture",
		Subcategory = "Chairs",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 8,
		},
	},		
	-------------------------------------------------------------------------
	-- CRAFT STATIONS
	-------------------------------------------------------------------------
	WoodsmithTable = 
	{
		MinLevelToCraft = 49,
		MaxLevelToGain = 89,
		DisplayName = "Carpentry Table",
		Description = "[$3152]",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "tool_carpentry_table",
		Category = "Furniture",
		Subcategory = "CraftingStations",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 250,
		},
	},
	InscriptionTable = 
	{
		MinLevelToCraft = 49,
		MaxLevelToGain = 89,
		DisplayName = "Inscription Table",
		Description = "Used to create items using the inscription skill.",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "workbench_inscription",
		Category = "Furniture",
		Subcategory = "CraftingStations",
		EnableCraftOrder = false,
		Resources = 
		{
			FrayedScroll = 30,
			Boards = 150,
		},
	},
	Loom = 
	{
		MinLevelToCraft = 49,
		MaxLevelToGain = 89,
		DisplayName = "Loom",
		Description = "[$3153]",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "tool_loom",
		Category = "Furniture",
		Subcategory = "CraftingStations",
		EnableCraftOrder = false,
		Resources = 
		{
			Cloth = 75,
			Boards = 125,
		},
	},
	AlchemyTable = 
	{
		MinLevelToCraft = 49,
		MaxLevelToGain = 89,
		DisplayName = "Alchemy Table",
		Description = "[$3154]",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "workbench_alchemy",
		Category = "Furniture",
		Subcategory = "CraftingStations",
		EnableCraftOrder = false,
		Resources = {
			Boards = 200,
		},
	},
	Anvil = 
	{
		MinLevelToCraft = 49,
		MaxLevelToGain = 89,
		DisplayName = "Anvil",
		NeedRecipe = true,
		CraftingTemplateFile = "tool_anvil",
		Description = "[$3163]",
		Category = "Furniture",
		Subcategory = "CraftingStations",
		EnableCraftOrder = false,
		Resources = {
			Boards = 50,
			Iron = 250,
		},
	},
	Stove = 
	{
		MinLevelToCraft = 49,
		MaxLevelToGain = 89,
		DisplayName = "Stove",
		NeedRecipe = true,
		CraftingTemplateFile = "stove",
		Description = "[$3165]",
		Category = "Furniture",
		Subcategory = "CraftingStations",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 50,
			Iron = 150,
		},
	},		
	-------------------------------------------------------------------------
	-- DECORATIVE ITEMS
	-------------------------------------------------------------------------
	Campfire = 
	{
		MinLevelToCraft = -5,
		MaxLevelToGain = 5,
		DisplayName = "Campfire",
		Description = "[$3147]",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "campfire",
		Category = "Furniture",
		Subcategory = "DecorativeItems",
		Resources = 
		{
			Wood = 5,
		},
	},	
	Shelf = 
	{
		MinLevelToCraft = 25,
		MaxLevelToGain = 55,
		DisplayName = "Shelf",
		Description = "[$3146]",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_shelf",
		Category = "Furniture",
		Subcategory = "DecorativeItems",
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = 1,
		},
	},	
	BedSmall = 
	{
		MinLevelToCraft = 50,
		MaxLevelToGain = 75,
		DisplayName = "Small Bed",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_bed_small",
		Description = "[$3130]",
		ItemType = "FurnitureClass",
		Category = "Furniture",
		Subcategory = "DecorativeItems",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 20,
		},
	},

	BedLarge = 
	{
		MinLevelToCraft = 25,
		MaxLevelToGain = 55,
		DisplayName = "Large Bed",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_bed_large",
		Description = "[$3131]",
		ItemType = "FurnitureClass",
		Category = "Furniture",
		Subcategory = "DecorativeItems",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 50,
		},
	},
	BedMedium = 
	{
		MinLevelToCraft = 25,
		MaxLevelToGain = 55,
		DisplayName = "Medium Bed",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_bed_medium",
		Description = "[$3132]",
		ItemType = "FurnitureClass",
		Category = "Furniture",
		Subcategory = "DecorativeItems",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 40,
		},
	},	
	BookshelfWooden = 
	{
		MinLevelToCraft = 25,
		MaxLevelToGain = 55,
		DisplayName = "Wooden Bookshelf",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_bookshelf_wooden",
		Description = "[$3135]",
		Category = "Furniture",
		Subcategory = "DecorativeItems",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 20,
		},
	},
	BookstandShort = 
	{
		MinLevelToCraft = 25,
		MaxLevelToGain = 55,
		DisplayName = "Short Bookstand",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_bookstand_short",
		Description = "Used for public reading of a Catalog that an adventurer is proud of completing.",
		Category = "Furniture",
		Subcategory = "DecorativeItems",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 10,
		},
	},
	BookstandTall = 
	{
		MinLevelToCraft = 25,
		MaxLevelToGain = 55,
		DisplayName = "Tall Bookstand",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_bookstand_tall",
		Description = "Used for public reading of a Catalog that an adventurer is proud of completing.",
		Category = "Furniture",
		Subcategory = "DecorativeItems",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 35,
		},
	},
	BookshelfOrnate = 
	{
		MinLevelToCraft = 25,
		MaxLevelToGain = 55,
		DisplayName = "Ornate Bookshelf",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_bookshelf_ornate",
		Description = "While primarily used for public reading and displaying of collections of Tomebooks, this furnishing can also look good with potions, statues, or other spoils of war.",
		Category = "Furniture",
		Subcategory = "DecorativeItems",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 80,
		},
	},
	BookshelfOrnateCorner = 
	{
		MinLevelToCraft = 25,
		MaxLevelToGain = 55,
		DisplayName = "Ornate Corner Bookshelf",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_bookshelf_ornate_corner",
		Description = "Angled corner piece that complements the 'Ornate Bookshelf' furnishing.",
		Category = "Furniture",
		Subcategory = "DecorativeItems",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 60,
		},
	},
	FireplaceStone = 
	{
		MinLevelToCraft = 25,
		MaxLevelToGain = 55,
		DisplayName = "Stone Fireplace",
		Description = "[$3142]",
		ItemType = "FurnitureClass",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_fireplace_stone",
		Category = "Furniture",
		Subcategory = "DecorativeItems",
		EnableCraftOrder = false,
		Resources = 
		{
			Stone = 100,
		},
	},	
	-------------------------------------------------------------------------
	-- LIGHTING
	-------------------------------------------------------------------------
	WallLantern = 
	{
		MinLevelToCraft = 59,
		MaxLevelToGain = 89,
		DisplayName = "Wall Lantern",
		Description = "",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_lantern_wall",
		Category = "Furniture",
		Subcategory = "Lighting",
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = 5,
		},
	},
	HangingLantern = 
	{
		MinLevelToCraft = 59,
		MaxLevelToGain = 89,
		DisplayName = "Hanging Lantern",
		Description = "",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_lantern_hanging",
		Category = "Furniture",
		Subcategory = "Lighting",
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = 5,
		},
	},
	StandingTorch = 
	{
		MinLevelToCraft = 59,
		MaxLevelToGain = 80,
		DisplayName = "Standing Torch",
		Description = "",
		NeedRecipe = true,
		CraftingTemplateFile = "furniture_standingtorch",
		Category = "Furniture",
		Subcategory = "Lighting",
		EnableCraftOrder = true,
		Resources = 
		{
			Boards = 5,
		},
	},
	Torch = 
	{
		MinLevelToCraft = -5,
		MaxLevelToGain = 5,
		DisplayName = "Torch",
		Description = "[$3157]",
		NeedRecipe = true,
		CraftingTemplateFile = "torch",
		Category = "Furniture",
		Subcategory = "Lighting",
		EnableCraftOrder = false,
		Resources = 
		{
			Boards = 1,
		},
	},		
	-------------------------------------------------------------------------
	-- STAVES
	-------------------------------------------------------------------------
	MageStaff = 
	{
		MinLevelToCraft = 20,
		MaxLevelToGain = 50,
		DisplayName = "Mage Staff",
		NeedRecipe = true,
		CraftingTemplateFile = "attuned_staff",
		Description = "Creates a lesser attuned magical staff. ",
		Category = "Equipment",
		Subcategory = "Staves",
		CanImprove = true,
		Resources = 
		{
			Boards = { Boards = 8 },
			EnchantedBoards = { EnchantedBoards = 8, Essence = 5, },		
		},
	},	
	PearlStaff = 
	{
		MinLevelToCraft = 20,
		MaxLevelToGain = 50,
		DisplayName = "Pearl Staff",
		NeedRecipe = true,
		CraftingTemplateFile = "attuned_pearl_staff",
		Description = "Creates a lesser attuned magical pearl staff. ",
		Category = "Equipment",
		CanImprove = true,
		Subcategory = "Staves",
		Resources = 
		{
			Boards = { Boards = 8 },
			EnchantedBoards = { EnchantedBoards = 8, Essence = 5, },		
		},
	},	
	WhiteStaff = 
	{
		MinLevelToCraft = 20,
		MaxLevelToGain = 50,
		DisplayName = "White Staff",
		NeedRecipe = true,
		CraftingTemplateFile = "attuned_white_staff",
		Description = "Creates a lesser attuned magical white staff. ",
		CanImprove = true,
		Category = "Equipment",
		Subcategory = "Staves",
		Resources = 
		{
			Boards = { Boards = 8 },
			EnchantedBoards = { EnchantedBoards = 8, Essence = 5, },		
		},
	},
	-------------------------------------------------------------------------
	-- WANDS
	-------------------------------------------------------------------------
	MasterWand = 
	{
		MinLevelToCraft = 10,
		MaxLevelToGain = 40,
		DisplayName = "Master Wand",
		NeedRecipe = true,
		CraftingTemplateFile = "attuned_master_wand",
		Description = "Creates a lesser attuned master wand. ",
		Category = "Equipment",
		Subcategory = "Wands",
		CanImprove = true,
		Resources = 
		{
			Boards = { Boards = 4 },
			EnchantedBoards = { EnchantedBoards = 4, Essence = 5, },		
		},
	},
	ApprenticeWand = 
	{
		MinLevelToCraft = 10,
		MaxLevelToGain = 40,
		DisplayName = "Apprentice Wand",
		NeedRecipe = true,
		CraftingTemplateFile = "attuned_master_wand",
		Description = "Creates a lesser attuned apprentice wand. ",
		Category = "Equipment",
		Subcategory = "Wands",
		CanImprove = true,
		Resources = 
		{
			Boards = { Boards = 4 },
			EnchantedBoards = { EnchantedBoards = 4, Essence = 5, },		
		},
	},
	NoviceWand = 
	{
		MinLevelToCraft = 10,
		MaxLevelToGain = 40,
		DisplayName = "Novice Wand",
		NeedRecipe = true,
		CraftingTemplateFile = "attuned_novice_wand",
		Description = "Creates a lesser attuned novice wand. ",
		Category = "Equipment",
		Subcategory = "Wands",
		CanImprove = true,
		Resources = 
		{
			Boards = { Boards = 4 },
			EnchantedBoards = { EnchantedBoards = 4, Essence = 5, },		
		},
	},
}