require 'default:globals.equipment'

function GetEquipmentTooltipTable(item, tooltipInfo)
	tooltipInfo = tooltipInfo or {}
	
	local weaponType = item:GetObjVar("WeaponType")
	if ( weaponType ) then
		if ( EquipmentStats.BaseWeaponStats[weaponType] ~= nil and EquipmentStats.BaseWeaponStats[weaponType].NoCombat ~= true ) then
			local weaponClass = EquipmentStats.BaseWeaponStats[weaponType].WeaponClass

			if( Weapon.UseBestWeaponSkill(item) ) then
				tooltipInfo.WeaponType = {
					TooltipString = "[FFE691]Versatile Weapon[-]",
					Priority = 6,
				}
			else
				-- add weapon type display name
				if ( EquipmentStats.BaseWeaponClass[weaponClass] and EquipmentStats.BaseWeaponClass[weaponClass].DisplayName ) then
					tooltipInfo.WeaponType = {
						TooltipString = EquipmentStats.BaseWeaponClass[weaponClass].DisplayName,
						Priority = 6,
					}
				end
			end

			

			-- add attack
			if ( EquipmentStats.BaseWeaponStats[weaponType].Attack ) then
				local bonus = item:GetObjVar("AttackBonus") or 0
				local str = " Attack"
				if ( bonus > 0 ) then str = string.format("%s (+%d%%)", str, bonus) end
				tooltipInfo.Attack = {
					TooltipString = EquipmentStats.BaseWeaponStats[weaponType].Attack..str,
					Priority = 5,
				}

				bonus = item:GetObjVar("AccuracyBonus") or 0
				if ( bonus > 0 ) then
					tooltipInfo.Accuracy = {
						TooltipString = string.format("+%d Accuracy", bonus),
						Priority = 4,
					}
                end
			end

			-- add speed tip
			if ( EquipmentStats.BaseWeaponStats[weaponType].Speed ) then
				tooltipInfo.Speed = {
					TooltipString = "Speed " .. EquipmentStats.BaseWeaponStats[weaponType].Speed,
					Priority = 3,
				}
			end

			-- add power
			if ( EquipmentStats.BaseWeaponStats[weaponType].Power ) then
				tooltipInfo.Power = {
					TooltipString = EquipmentStats.BaseWeaponStats[weaponType].Power.." Power",
					Priority = 2,
				}
			end

			-- add force
			if ( EquipmentStats.BaseWeaponStats[weaponType].Force ) then
				tooltipInfo.Force = {
					TooltipString = EquipmentStats.BaseWeaponStats[weaponType].Force.." Force",
					Priority = 1,
				}
			end
		end
	end

	local armorType = item:GetObjVar("ArmorType")
	if ( armorType ) then
		if ( EquipmentStats.BaseArmorStats[armorType] ~= nil ) then
			local armorClass = EquipmentStats.BaseArmorStats[armorType].ArmorClass
			local equipSlot = GetEquipSlot(item)

			-- add armor class
			tooltipInfo.ArmorClass = {
				TooltipString = armorClass,
				Priority = 20,
			}
			
			-- add armor rating
			local bonus = item:GetObjVar("ArmorBonus") or 0
			if ( bonus > 0 ) then
				tooltipInfo.ArmorRating = {
					TooltipString = string.format("+%d Defense", bonus),
					Priority = 3,
				}
			end

			-- add evasion bonus
			local bonus = item:GetObjVar("EvasionBonus") or 0
				if ( bonus > 0 ) then
					tooltipInfo.Evasion = {
						TooltipString = string.format("+%d Evasion", bonus),
						Priority = 4,
					}
                end

			-- add stamina regen modifier
			local staminaModifier = EquipmentStats.BaseArmorClass[armorClass][equipSlot].StaRegenModifier or 0
			if ( staminaModifier > 0 ) then
				tooltipInfo.StamMod = {
					TooltipString = staminaModifier .. " Stamina Regeneration",
					Priority = 2,
				}
			end

			--[[ TODO: Re-enabled per item mana regen bonus
			--add mana regen modifier
			local manaModifier = EquipmentStats.BaseArmorStats[armorType][equipSlot].ManaRegenModifier or 0
			if ( manaModifier > 0 ) then
				tooltipInfo.ManaMod = {
					TooltipString = "+"..manaModifier .. " Mana Regeneration",
					Priority = 1,
				}
			end
			]]
		end
	end

	local shieldType = item:GetObjVar("ShieldType")
	if ( shieldType ) then

		local bonus = item:GetObjVar("ArmorBonus") or 0
		local str = " Armor Rating"
		if ( bonus > 0 ) then str = string.format("%s (+%d)", str, bonus) end

		-- add armor rating
		tooltipInfo.ArmorRating = {
			TooltipString = EquipmentStats.BaseShieldStats[shieldType].ArmorRating .. str,
			Priority = 3,
		}

		--add mana regen modifier
		local manaModifier = EquipmentStats.BaseShieldStats[shieldType].ManaRegenModifier or 0
		if ( manaModifier > 0 ) then
			tooltipInfo.ManaMod = {
				TooltipString = "+"..manaModifier .. " Mana Regeneration",
				Priority = 1,
			}
		end

	end
	-------------------------------------------------------------------------------------------------
	-- my jewelryType is not existant, this fixes a crash on item generation while crafting
	-------------------------------------------------------------------------------------------------
	-- testing typeData for nil
	local jewelryType = item:GetObjVar("JewelryType")
	if ( jewelryType ) then
		local typeData = JewelryTypeData[jewelryType]
		if(typeData) then
			if ( typeData.Will ) then
				tooltipInfo.WillStatMod = {
					TooltipString = string.format("+%s Will", typeData.Will),
					Priority = 3,
				}
			end
			if ( typeData.Wis ) then
				tooltipInfo.WisStatMod = {
					TooltipString = string.format("+%s Wisdom", typeData.Wis),
					Priority = 3,
				}
			end
			if ( typeData.Health ) then
				tooltipInfo.ConStatMod = {
					TooltipString = string.format("+%s Health", typeData.Health),
					Priority = 3,
				}
			end
		end
	end
	-- this rest of this function only applies to weapons and armor (stuff that can be equipped in hand or on body)
	if ( not weaponType and not armorType and not shieldType and not jewelryType ) then return tooltipInfo end


	-- add durability.
	if( not(item:HasObjVar("Blessed")) ) then
		local durabilityString = GetDurabilityString(item)
		if ( durabilityString ) then
			tooltipInfo.Durability = {
				TooltipString = durabilityString,
				Priority = -99999,
			}
		end
	end

	return tooltipInfo
end