-- get the basic infromation of the chaos helper
require 'default:globals.helpers.chaos'

ChaosZoneHelper = {}
ChaosZoneHelper.Regions = {}
-- include our tables for each region
require 'chaoszones.main'

-- this function checks to see if the player is chaotic
--@param (GameObject) player - the player entering the chaos zone
function ChaosZoneHelper.IsPlayerChaotic( player )
    return ( player and player:IsValid() and HasMobileEffect( player, "Chaos" ) )
end

--- this checks to see if the chaos zone is active
--@param (GameObject) player - the player entering the chaos zone
--@param (strubg) regionName - the name of the region to check if its active
function ChaosZoneHelper.IsChaosZoneActive( player , regionName)
    if(ChaosZoneHelper.Regions[ServerSettings.WorldName].RegionData[regionName].Active) then
        return true 
    end
    return false    
end

-- this checks to see if the player is in a chaos zone
--@param (GameObject) player - the player entering the chaos zone
function ChaosZoneHelper.IsPlayerInChaosZone( player )
    local regionalName = GetRegionalName(player:GetLoc())
    local worldName = ServerSettings.WorldName
    if(worldName == "NewCelador") then
        worldName = ServerSettings.SubregionName
    end
    local regionalTable = ChaosZoneHelper.Regions[worldName].RegionNames
    
    if(regionalTable) then
        for index,value in pairs(regionalTable) do
            if( player and player:IsValid() and player:IsInRegion(value) and ChaosZoneHelper.IsChaosZoneActive( player , value)) then
                return true
            end            
        end
    end
    return false
end

-- NOTES
-- this function requires a override in helpers/criminal.lua
-- we need to pass the object to check the region
-- this checks to see if a location is in a chaos zone
--@param (GameObject) player - the player entering the chaos zone
function ChaosZoneHelper.IsLocInChaosZone(player, loc)
    local regionalName = GetRegionalName(player:GetLoc())
    local regionalTable = ChaosZoneHelper.Regions[ServerSettings.WorldName].RegionNames
    if(regionalTable) then
        for index,value in pairs(regionalTable.RegionNames) do
            if( loc and IsLocInRegion(loc,value)) then
                return true
            end            
        end
    end
    return false
end

-- this check is ran in the player.lua to check every 1 second if the player is in a chaos zone
--@param (GameObject) player - the player entering the chaos zone
function ChaosZoneHelper.ChaosZoneCheck( player )
    local hasChaosEffect = ChaosZoneHelper.IsPlayerChaotic(player)
    local regionalName = GetRegionalName(player:GetLoc())
    local regionalTable = ChaosZoneHelper.Regions[ServerSettings.WorldName].RegionNames
    local isInChaosRegion = false
    -- check if we are in a region
    if(regionalTable) then
        for index,value in pairs(regionalTable) do
            if(ChaosZoneHelper.IsChaosZoneActive( player , value) and regionalName == value) then
                isInChaosRegion = true
            end
        end
    end
    -- if the player entered a chaso region and dont have the mobile effect Chaos then give them the mobile effect Chaos
    if(player and player:IsValid() and isInChaosRegion and not hasChaosEffect) then 
        player:SendMessage("StartMobileEffect", "Chaos")
        StartMobileEffect(player,"ChaosMods",player)

        if(ChaosZoneHelper.Regions[ServerSettings.WorldName].RegionData[regionalName].OnEnterMessage) then 
            player:SystemMessage(ChaosZoneHelper.Regions[ServerSettings.WorldName].RegionData[regionalName].OnEnterMessage)
        end
        if(ChaosZoneHelper.Regions[ServerSettings.WorldName].RegionData[regionalName].OnEnterEffect) then
            player:PlayEffect(ChaosZoneHelper.Regions[ServerSettings.WorldName].RegionData[regionalName].OnEnterEffect.Name,ChaosZoneHelper.Regions[ServerSettings.WorldName].RegionData[regionalName].OnEnterEffect.Duration)
        end

        return
    end
    -- if the player has the chaos effect but is no longer in a choas region, then remove the mobile effect 
    if (player and player:IsValid() and hasChaosEffect and not isInChaosRegion) then 
        player:SendMessage("EndChaosEffect") 
        StartMobileEffect(player,"ChaosModsRemove",player)
        player:SystemMessage("[FF7700] you begin to feel normal again...")
    end
end

