require 'default:globals.helpers.crafting'

RunicKnowledgePropertyChances =
{
	{
		SkillLevelMin = 60, -- 1 in 3 chance of 2 properties
		PropertyChances = {1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2},
	},
	{
		SkillLevelMin = 75, -- 1 in 10 chance of 3 properties
		PropertyChances = {1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3},
	},
	{
		SkillLevelMin = 85, -- 1 in 30 chance at 4 properties
		PropertyChances = {1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,4},
	},
	{
		SkillLevelMin = 95, -- 1 in 10 chance at 4 properties
		PropertyChances = {1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3,4,4,4},
	},
}

function GetRunicKnowledge(objRef)
	local crafter = objRef:GetObjVar("Crafter")
	local propertyCount = 1
	if(crafter) then
		local runicKnowledgeSkill = GetSkillLevel(crafter,"RunicKnowledgeSkill")
		CheckSkillChance(crafter, "RunicKnowledgeSkill", runicKnowledgeSkill,SkillValueMinMax(runicKnowledgeSkill, 0, 100))
		for i,v in ipairs(RunicKnowledgePropertyChances) do
			if(runicKnowledgeSkill >= v.SkillLevelMin) then
				propertyCount = math.random(v.PropertyChances[#v.PropertyChances])
			end	
		end		
	end

	return propertyCount
end

--- When crafting something out of a material (vs a resource) the resource get a weighted roll dependant on the type of material
--- Note: This is expected to be called BEFORE setting tooltips on the item!
-- @param objRef(GameObj) The recently created object.
-- @param material(string) The string name of the material the item was created from
-- @param skillLevel(number) The skill level of the skill used to create the item
-- @return none
function ApplyCraftedMaterialProperties(objRef, material, skillLevel)
	if ( objRef == nil ) then
		LuaDebugCallStack("[ApplyCraftedMaterialProperties] Nil objRef provided.")
		return
	end
	if ( Materials[material] == nil ) then
		LuaDebugCallStack("[ApplyCraftedMaterialProperties] Invalid material '"..tostring(material).."' provided.")
		return
	end
	if ( skillLevel == nil ) then
		LuaDebugCallStack("[ApplyCraftedMaterialProperties] Invalid skillLevel '"..tostring(skillLevel).."' provided.")
		return
	end
	local skillPercent = skillLevel / ServerSettings.Skills.PlayerSkillCap.Single
	local totalProps = 1
	local baseDurabilityBonus = math.random(10,20) + GetMaxDurabilityValue(objRef)

	totalProps = GetRunicKnowledge(objRef)

	-- custom crafting magical items
	if(material=="EnchantedIron" or material=="EnchantedCloth" or material=="EnchantedLeather" or material=="EnchantedBoards") then
		local equipmentType = objRef:GetObjVar("WeaponType") or objRef:GetObjVar("ArmorType") or objRef:GetObjVar("ShieldType") or objRef:GetObjVar("JewelryType")
		if(equipmentType) then
			ApplyEquipmentProperties(objRef,equipmentType,totalProps)
			--objRef:SetObjVar("Enchants",essenceTable)
			local propCount = #objRef:GetObjVar("Enchants") or 1
			local colorText = "[44CC44]"
			if(propCount==2) then colorText = "[4444CC]" end
			if(propCount==3) then colorText = "[CCCC44]" end
			if(propCount>3) then colorText = "[CC44CC]" end
			objRef:SetName(colorText.."Enchanted " .. StripColorFromString(objRef:GetName()) .. "[-]")
		end
	end
	-- handle durability bonus
	objRef:SetObjVar("MaxDurability", baseDurabilityBonus)
	SetItemTooltip(objRef)
end

function GetItemCraftedMaterial(item,recipeTable)
	local material = item:GetObjVar("Material")
	if(material) then
		return material
	end

	if not(recipeTable)  then
		recipeTable = GetRecipeForBaseTemplate(itemBaseTemp)		
	end

	if(recipeTable and recipeTable.CanImprove) then
		for materialType,v in pairs(recipeTable.Resources) do
			for skillName,materialList in pairs(MaterialIndex) do
				local baseMaterial = materialList[1]
				if(materialType == baseMaterial) then
					return materialType
				end

				-- HACK: Fabrication has two base materials!
				if(skillName == "FabricationSkill") then
					baseMaterial = materialList[2]
					if(materialType == baseMaterial) then
						return materialType
					end
				end
			end
		end
	end
end