require 'default:globals.helpers.criminal'

--- Determine if an action to another player is a criminal action
-- @param mobileA | the player performing the action
-- @param mobileB | the mobile the action is performed on
-- @param beneficial
-- @return bool
function IsCriminalAction(mobileA, mobileB, beneficial)
	Verbose("Criminal", "IsCriminalAction", mobileA, mobileB, beneficial)
    if ( mobileA == nil ) then
        LuaDebugCallStack("[Criminal] Nil mobileA provided.")
        return false
    end
    if ( mobileB == nil ) then
        LuaDebugCallStack("[Criminal] Nil mobileB provided.")
        return false
    end

    -- ensure mobileA is not mobileB and mobileB is in the same region.
    if ( mobileB == mobileA or not mobileB:IsValid() ) then return false end
    
    -- criminal actions can only be applied to players
    if not( IsPlayerCharacter(mobileA) ) then return false end

    local owner = mobileB:GetObjVar("controller")

    -- explicitly stop all criminal actions on your own pets/followers.
    if ( mobileA == owner ) then return false end

    -- If this is a corpse we need to keep a refrence to it
    local corpse = nil
    if( owner and mobileB:GetCreationTemplateId() == "player_corpse" ) then
        corpse = mobileB
    end

    -- reassign to owner
    local isPlayerB = IsPlayerObject(mobileB)
    if ( owner and owner:IsValid() and not IsPossessed(mobileB)) then mobileB = owner end

    -- ensure they are both within an area crimes matter
    if ( mobileB ~= nil and (not WithinCriminalArea(mobileA) and not WithinCriminalArea(mobileB)) ) then
        return false
    end

    if ( isPlayerB ) then
        -- if target is criminal only a crime to benefit them, if not beneficial it's not criminal if they are criminal
        if ( beneficial ) then return IsCriminal(mobileB) elseif ( IsCriminal(mobileB) ) then return false end

        -- non beneficial actions are not crimes when both players have consented.
        if ( not beneficial and ShareGroupConsent(mobileA, mobileB) ) then return false end

        -- players in opposing factions are not commiting crimes
        if ( Militia.InOpposing(mobileA, mobileB) ) then return false end

        -- Are both players in a chaotic zone?
        --DebugMessage( "mobileA", tostring( ChaosZoneHelper.IsPlayerChaotic(mobileA) ) )
        --DebugMessage( "mobileB.1", tostring( ChaosZoneHelper.IsPlayerChaotic(mobileB) ) )
        --DebugMessage( "mobileB.2", tostring( (corpse and ChaosZoneHelper.IsLocInChaosZone(corpse:GetLoc())) ) )
        if( ChaosZoneHelper.IsPlayerChaotic(mobileA) and (ChaosZoneHelper.IsPlayerChaotic(mobileB) or (corpse and ChaosZoneHelper.IsLocInChaosZone(corpse,corpse:GetLoc())) ) ) then return false end

        -- players in an arena match
        if(RankedArena.InRankedArenaMatch(mobileA, mobileB) ) then return false end

        -- players in guild wars are not commiting crimes
        if ( GuildHelpers.InGuildWarWith(mobileA, mobileB) ) then return false end
    else
        if ( not mobileB:HasObjVar("ImportantNPC") and not mobileB:HasObjVar("GuardProtect") ) then
            return false
        elseif ( beneficial and (mobileB:HasObjVar("ImportantNPC") or mobileB:HasObjVar("GuardProtect") ) ) then
            return false
        end
    end

    if ( not beneficial and IsAggressorTo(mobileB, mobileA) ) then
        -- victim/defender action against aggressor, no crime.
        return false
    end

    return true
end