require 'default:globals.helpers.loottables'

-- LootTables is an array of loot tables
-- Each table can have the following values
--   NumCoins - The number of coins to spawn in the container
-- NOTE: itemCreatedOverride should still call LootItemCreated to set stack, color etc
function LootTables.SpawnLoot(lootTables,destContainer,objVars,autoStack,guardProtection,notify)
	--DebugMessage(1)
	-- fill the mob's backpack
	if( lootTables ~= nil ) then
		local topCont = destContainer:TopmostContainer()

		-- if this mob has money
		--D*ebugTable(curLootTable)
		--DebugMessage(2)

		-- add up all the coins
		local totalCoins = 0
		for key, subTable in pairs(lootTables) do
			local numCoins = subTable.NumCoins or 0
			if(subTable.NumCoinsMin or subTable.NumCoinsMax) then
				numCoins = math.random((subTable.NumCoinsMin or 0),(subTable.NumCoinsMax or 0))
			end
			totalCoins = totalCoins + numCoins
		end
		if(totalCoins > 0) then
			if(guardProtection == "None") then
				totalCoins = math.ceil(totalCoins * ServerSettings.Misc.WildernessModifiers.Gold)
			end
			local dropPos = GetRandomDropPosition(destContainer)
			RegisterSingleEventHandler(EventType.CreatedObject, "LootCoinPurse", LootCoinPurseCreated)

			if( topCont and topCont:IsMobile() and topCont:HasObjVar("TagKillers") ) then
				local killers = topCont:GetObjVar("TagKillers")

				if( killers[1] ) then
					RequestMobileMod( topCont, killers[1], {"GoldIncreaseTimes"},
					function(MobileMod)
						--DebugMessage("TotalCoins: " .. totalCoins)
						totalCoins = math.floor( totalCoins * ( 1 + (GetMobileMod(MobileMod.GoldIncreaseTimes, 0) / 100) ) )
						--DebugMessage("TotalCoins: " .. totalCoins)
						CreateObjInContainer("coin_purse", destContainer, dropPos, "LootCoinPurse", totalCoins,objVars)
						LoottablesNotify(notify, topCont, "coin_purse", totalCoins)
					end)
				else
					CreateObjInContainer("coin_purse", destContainer, dropPos, "LootCoinPurse", totalCoins,objVars)
					LoottablesNotify(notify, topCont, "coin_purse", totalCoins)
				end

			else
				CreateObjInContainer("coin_purse", destContainer, dropPos, "LootCoinPurse", totalCoins,objVars)
				LoottablesNotify(notify, topCont, "coin_purse", totalCoins)
			end
			
		end

		-- Does the container have enchanted items that can drop?
		local lootLevel = nil

		-- Is this a container?
		if( destContainer ) then
			lootLevel = destContainer:GetObjVar("LootLevel")
		end

		-- Is this a mobile? 
		if( topCont ) then
			lootLevel = topCont:GetObjVar("LootLevel")
		end


		--DebugMessage("LootLevel", lootLevel)

		if( lootLevel ) then
			--ProcessRandomEnchantLoot( lootLevel, destContainer )				
		end
		
		local itemsSpawned = {}
		for key, subTable in pairs(lootTables) do
			local skipLootTable = false
			if(subTable.Chance) then
				skipLootTable = not(Success(subTable.Chance/100))
			end
			--DebugMessage(3)
			-- if the mob has items
			if( not(skipLootTable) and subTable.LootItems ~= nil ) then
				local itemCount = subTable.NumItems or #subTable.LootItems
				if(subTable.NumItemsMin or subTable.NumItemsMax) then
					itemCount = math.random((subTable.NumItemsMin or 0),(subTable.NumItemsMax or 0))
				end
				--DebugMessage("MIN: "..subTable.MinItems..", MAX: "..subTable.MaxItems..", COUNT: "..itemCount)
				if(itemCount > 0) then
					--DebugMessage(DumpTable(subTable.LootItems))
					local multiplier = 1
					if(guardProtection == "None") then
						multiplier = ServerSettings.Misc.WildernessModifiers.LootRoll
					end
					local availableItems = FilterLootItemsByChance(subTable.LootItems,multiplier)

					--DebugMessage(DumpTable(availableItems))

					for i=1,itemCount do
						if( availableItems and next(availableItems) ) then
							local itemIndex = GetRandomLootItemIndex(availableItems)
							local itemTemplateId = availableItems[itemIndex].Template
							local color = availableItems[itemIndex].Color
							local stackCount = availableItems[itemIndex].StackCount or 1
							if(availableItems[itemIndex].StackCountMin or availableItems[itemIndex].StackCountMax) then
								stackCount = math.random((availableItems[itemIndex].StackCountMin or 0),(availableItems[itemIndex].StackCountMax or 0))
							end
							--DebugMessage("itemIndex is "..tostring(itemIndex))
							--DebugMessage(tostring(availableItems[itemIndex]).." is bleh")
							--DebugMessage(tostring(availableItems[itemIndex].Templates).." is narm")
							-- if its unique then remove it from the list

							if (availableItems[itemIndex].Templates ~= nil) then
								for index,template in pairs(availableItems[itemIndex].Templates) do

									local dropPos = GetRandomDropPosition(destContainer)
									--DebugMessage("itemTemplateId: "..(tostring(template)))
									CreateObjInContainer(template, destContainer, dropPos, "LootObject",stackCount,color,callback,objVars)
									LoottablesNotify(notify, topCont, template, stackCount)
									table.insert(itemsSpawned, template)
								end

							else								
								local dropPos = GetRandomDropPosition(destContainer)

								if ( availableItems[itemIndex].Packed ) then
									Create.PackedObject.InContainer(itemTemplateId, destContainer, dropPos)
									LoottablesNotify(notify, topCont, itemTemplateId, 1)
									table.insert(itemsSpawned, itemTemplateId)
								else
									local shouldCreate = true
									if(autoStack) then
										local resourceType = GetTemplateObjVar(itemTemplateId, "ResourceType")
										shouldCreate = not(TryAddToStack(resourceType, destContainer, stackCount) )
									end

									if(shouldCreate) then
										CreateObjInContainer(itemTemplateId, destContainer, dropPos, "LootObject",stackCount,color,objVars)
									end

									LoottablesNotify(notify, topCont, itemTemplateId, stackCount)
									table.insert(itemsSpawned, itemTemplateId)
								end

								if( availableItems[itemIndex].Unique == true ) then								
									table.remove(availableItems,itemIndex)
								end
							end
							--itemsSpawned = itemsSpawned + 1
						end
					end					
				end
			end
		end

		if(#itemsSpawned > 0) then
			-- NOTE: This never gets unregistered
			RegisterEventHandler(EventType.CreatedObject, "LootObject", LootItemCreated)

			CallFunctionDelayed(TimeSpan.FromMilliseconds(1),function()
				--move items inside pouch
				if ( destContainer:IsMobile() and IsDead(destContainer) ) then
					local pouchObj = FindObjectInContainer(destContainer, "pouch")
					if ( pouchObj ) then
						TransferContainerContents(destContainer, pouchObj)
					end
				end
			end)
		end

		return itemsSpawned
	end
end
