require 'incl_gametime'
require 'mega_spawner.mega_spawner_user_interface'
require 'mega_spawner.mega_spawner_user_interface_response'
isDungeon = IsDungeonMap()

MegaSpawnerDefaults =
{
    DelayInSeconds = 180,
    Count = 1,
    Chance = 1,
    PulseFrequency = 10
}

-- the delay between spawn amounts, can be overridden by adding "spawnCount" objvar

mSpawnPower = nil

mIsPendingCreate = false

function GetSpawnPulse()    
    local delaySecs = this:GetObjVar("spawnPulseSecs") or MegaSpawnerDefaults.PulseFrequency
    return TimeSpan.FromSeconds(delaySecs + math.random())
end

function GetSpawnDelay()
    local delaySecs = this:GetObjVar("spawnDelay") or MegaSpawnerDefaults.DelayInSeconds
    return TimeSpan.FromSeconds(delaySecs + math.random())
end

--------------------------------------------------------------------------------------
--- citadels core GetSpawnLocation function override
--- the purpose of this override is to change how tables work with
--- the object variables spawnRegions. 
--------------------------------------------------------------------------------------
function GetSpawnLoc()    
    local spawnRegion = nil
    if(this:HasObjVar("spawnRegions")) then  
        -- first break down the string provided by spawnRegions into an array
        local regionList = StringSplit(this:GetObjVar("spawnRegions"),",")
        -- randomly pick one of the spawnTable templates provided by spawnList
        spawnRegion = regionList[math.random(#regionList)]
    else
        spawnRegion = this:GetObjVar("spawnRegion")
    end
    if(spawnRegion) then
        if(isDungeon) then
            return GetRandomDungeonSpawnLocation(spawnRegion)
        else
            return GetRandomPassableLocation(spawnRegion,true)
        end
    end
    local spawnRadius = this:GetObjVar("spawnRadius")
    if(spawnRadius) then
        if(isDungeon) then
            return GetRandomDungeonSpawnLocationInRange(this:GetLoc(), spawnRadius)
        else
            return GetRandomPassableLocationInRadius(this:GetLoc(),spawnRadius,true)
        end
    end    
    return this:GetLoc()
end

--------------------------------------------------------------------------------------
--- specialized custom function to determine what spawns
--------------------------------------------------------------------------------------
function DetermineSpawnTemplate()
    local spawnTable = this:GetObjVar("spawnTable")
    -- Check if we have a spawnTable
    if(spawnTable) then
        -- first break down the string provided by spawnTable into an array
        local spawnList = StringSplit(spawnTable,",")
        -- randomly pick one of the spawnTable templates provided by spawnList
        return spawnList[math.random(#spawnList)]       
    end
    -- lets use the default method
    if (this:HasObjVar("spawnTemplate")) then
        return this:GetObjVar("spawnTemplate")
    end
    return nil    
end
--------------------------------------------------------------------------------------
--- specialized custom function to determine if a rare template can appear or not
--------------------------------------------------------------------------------------
function CanRareBeSpawned()
    if(this:HasObjVar("spawnRareChance")) then
        local spawnRareChance = this:GetObjVar("spawnRareChance") or 0
        -- can spawn
        if(math.random() < spawnRareChance) then return true end
    end
    -- cant spawn
    return false
end
--------------------------------------------------------------------------------------
--- specialized custom function to determine which rare template to select to spawn
--------------------------------------------------------------------------------------
function DetermineSpawnTemplateForRareMobiles()
    local spawnRareTable = this:GetObjVar("spawnRareTable")
    if(spawnRareTable) then
        -- first break down the string provided by spawnTable into an array
        local spawnRareList = StringSplit(spawnRareTable,",")
        -- randomly pick one of the spawnTable templates provided by spawnList
        return spawnRareList[math.random(#spawnRareList)]       
    end    
    -- lets use the default spawnRareTemplate
    if (this:HasObjVar("spawnRareTemplate")) then
        return this:GetObjVar("spawnRareTemplate")
    end
end

function ShouldSpawn(spawnData, spawnIndex, templateId)
    if(mIsPendingCreate) then
        return false
    end

    local isValid = spawnData[spawnIndex].ObjRef and spawnData[spawnIndex].ObjRef:IsValid()
    local isDead = isValid and spawnData[spawnIndex].ObjRef and spawnData[spawnIndex].ObjRef:IsMobile() and IsDead(spawnData[spawnIndex].ObjRef)

    -- the mob is still on the map and hes not a pet, no spawn
    if( isValid and not(isDead) and not(IsPet(spawnData[spawnIndex].ObjRef)) ) then
        return false
    end

    -- If a spawn already exists at our spot we need to not spawn at all!
    if( FoundSpawn(templateId) ) then
        return false
    end

    local spawnDelay = GetSpawnDelay(spawnInfo)
    local spawnSpeedModifier = HelperSpawns.CalculateSpawnSpeedModifier(this, mSpawnPower) or mDefaultSpawnSpeedModifier
    --DebugMessage("spawnSpeedModifier [simple_mob_spawner] " .. tostring(spawnSpeedModifier))
    spawnDelay = TimeSpan.FromSeconds( spawnDelay.TotalSeconds * spawnSpeedModifier )
    --DebugMessage(this,"Checking spawnDelay [simple_mob_spawner] "..tostring(spawnDelay.TotalSeconds))
    if(spawnDelay.TotalSeconds ~= 0) then
        -- this mob just disappeared or died
        local goneTime = spawnData[spawnIndex].GoneTime
        if( spawnData[spawnIndex].ObjRef and not(goneTime) ) then  
            --DebugMessage(this,"MOB DEAD OR DESPAWNED")   
            spawnData[spawnIndex].GoneTime = DateTime.UtcNow
            return false
        end

        -- are we waiting on the spawn timer
        if(goneTime and DateTime.UtcNow < (goneTime + spawnDelay)) then
            --DebugMessage(this,"Waiting on spawn timer")   
            return false
        end
    end

    -- roll to spawn
    local spawnChance = this:GetObjVar("spawnChance") or MegaSpawnerDefaults.Chance
    if(spawnChance < 1 and math.random() > spawnChance) then   
        spawnData[spawnIndex].GoneTime = DateTime.UtcNow
        return false
    end

    return true
end
--------------------------------------------------------------------------------------
--- citadels core CheckSpawn function override
--- the purpose of this override is to change how this works with our new object
--- variables. I cleaned up the commenting, removed the day/night garbage,
--- added in 2 function calls DetermineSpawnTemplates which is a isolated function
--- to help allow you to make your own object variables mods. 
--------------------------------------------------------------------------------------
function CheckSpawn()
    local spawnData = this:GetObjVar("spawnData")        
    local spawnCount = this:GetObjVar("spawnCount") or MegaSpawnerDefaults.Count
    local templateId = nil   
    -- restart the timer for next pulse
    this:ScheduleTimerDelay(GetSpawnPulse(), "spawnTimer")
    -- can use put this on any spawner to disable it from another
    -- script. if you want to be able to turn them off when nobody is around.
    if (this:HasObjVar("Disable")) then return end
    -- citadels dynamic spawner system which I wont be using but left here
    -- to keep compliance with the loa code base
    if( HelperSpawns.IsDynamicProximitySpawner(this) ) then
        -- If we don't have the spawn power already we need to calculate it
        if( mSpawnPower == nil ) then
            --DebugMessage("Calculating Spawn Power")
            mSpawnPower = HelperSpawns.CalculateFullSpawnPower(this)
        end
    end
    -- function to determine how to select a template to spawn from
    -- the various methods in which we can pick them
    templateId = DetermineSpawnTemplate()
    -- lets check for a rare spawn chance if so lets spawn it instead
    if(CanRareBeSpawned()) then
        local perviousTemplateId = templateId
        templateId = DetermineSpawnTemplateForRareMobiles()
        if(templateId == nil) then
            templateId = perviousTemplateId
        end
    end
    -- we still do not have a template so something went wrong lets close the function out
    if( templateId == nil ) then return end
    -- clean up tables
    if spawnData == nil then
        spawnData = {}
    elseif #spawnData > spawnCount then
        for i=spawnCount+1,#spawnData do
            table.remove(spawnData,i)
        end
    end        
    -- spawn the object
    for i=1, spawnCount do
        if(spawnData[i] == nil) then spawnData[i] = {} end
        if( ShouldSpawn(spawnData, i, templateId) ) then   
            local spawnLoc = GetSpawnLoc()
            if(spawnLoc) then
                mIsPendingCreate = true
                CreateObj(templateId, spawnLoc, "mobSpawned", i)                    
                break
            end
        end
    end
    this:SetObjVar("spawnData", spawnData)
    UpdateMegaSpawnerProperties()    
end


function FoundSpawn( templateId ) 
    nearbyObjects = FindObjects(SearchTemplate(templateId,1))
    if (#nearbyObjects > 0) then
        for i=1, #nearbyObjects do 
            local foundObj = nearbyObjects[i]
            if( foundObj ~= objref ) then
                return true
            end
        end
    end
    return false
end


function MobSpawned(success, objref, index)
    mIsPendingCreate = false
    
    if( success) then

        -- If we find something that has spawned right beside us we want to delete it
        CallFunctionDelayed(TimeSpan.FromSeconds(math.random( 1,10 )),function()
            if( FoundSpawn( objref:GetCreationTemplateId() ) ) then
                --objref:Destroy()
            end
        end)

        local spawnData = this:GetObjVar("spawnData") 
        if(spawnData[index]) then
            spawnData[index].ObjRef = objref
            spawnData[index].GoneTime = nil
        else
            spawnData[index] = { ObjRef = objref }
        end            
        this:SetObjVar("spawnData",spawnData)
        objref:SetObjVar("Spawner",this)
        --DebugMessage("Set facing to " .. tostring(this:GetFacing()))
        if(objref:IsMobile()) then
            if(this:HasObjVar("spawnRadius")) then
                objref:SetFacing(math.random() * 360)
            else
                objref:SetFacing(this:GetFacing())
            end
        end

        local spawnObjVars = this:GetObjVar("spawnObjVars")
        if(spawnObjVars) then
            for varName,varData in pairs(spawnObjVars) do
                objref:SetObjVar(varName,varData)
            end
        end

        local spawnPath = this:GetObjVar("spawnPath")
        if( spawnPath ) then
            objref:SetObjVar("MyPath",spawnPath)
        end

    end
end

function UpdateMegaSpawnerProperties()
    local descriptionColor = "[959555]"    
    local valueColor = "[c5c595]"
    RemoveTooltipEntry(this,"megaSpawnerTopText")
    SetTooltipEntry(this,"megaSpawnerTopText","[FF7700] Standard Spawner Attributes",1100)
    if(this:HasObjVar("spawnCount")) then
        RemoveTooltipEntry(this,"megaSpawnerCount")
        SetTooltipEntry(this,"megaSpawnerCount",descriptionColor .. "Maximum number to Spawn: " .. valueColor .. (this:GetObjVar("spawnCount") or MegaSpawnerDefaults.Count) .. "[-]",1000)
    end
    if(this:HasObjVar("spawnDelay")) then
        RemoveTooltipEntry(this,"megaSpawnerDelay")
        SetTooltipEntry(this,"megaSpawnerDelay",descriptionColor .. "Delay in Seconds: " .. valueColor .. (this:GetObjVar("spawnDelay") or MegaSpawnerDefaults.DelayInSeconds) .. "[-]",990)
    end
    if(this:HasObjVar("spawnTemplate")) then
        RemoveTooltipEntry(this,"megaSpawnerTemplate")
        SetTooltipEntry(this,"megaSpawnerTemplate",descriptionColor .. "Template to Spawn: " .. valueColor .. (this:GetObjVar("spawnDelay") or "No Template Provided") .. "[-]",980)
    end   
    if(this:HasObjVar("spawnRareTemplate")) then
        RemoveTooltipEntry(this,"megaSpawnerRareTemplate")
        SetTooltipEntry(this,"megaSpawnerRareTemplate",descriptionColor .. "Rare Template to Spawn: " .. valueColor .. this:GetObjVar("spawnRareTemplate") .. "[-]",970)
    end 
    if(this:HasObjVar("spawnRareTable")) then
        RemoveTooltipEntry(this,"megaSpawnerRareTable")
        local spawnRareTable = StringSplit(this:GetObjVar("spawnRareTable"),",")
        local propertyString = "[FF7700]Possible Rare Templates To Spawn\n"
        for i=1,#spawnRareTable do
            if(i==#spawnRareTable) then
                propertyString = propertyString .. "[FFFFFF]" .. spawnRareTable[i]
            else
                propertyString = propertyString .. "[FFFFFF]" .. spawnRareTable[i] .. "\n"
            end
        end
        propertyString = propertyString .. "\n" .. ((this:GetObjVar("spawnRareChance")*100) or 100) .."% Chance to spawn"
        SetTooltipEntry(this,"megaSpawnerRareTable",descriptionColor .. propertyString,960)
    end     

    if(this:HasObjVar("spawnRegions")) then
        RemoveTooltipEntry(this,"megaSpawnerRegions")
        local spawnRegions = StringSplit(this:GetObjVar("spawnRegions"),",")
        local propertyString = "[FF7700]Possible Regions to Spawn In\n"
        for i=1,#spawnRegions do
            if(i==#spawnRegions) then
                propertyString = propertyString .. "[FFFFFF]" .. spawnRegions[i]
            else
                propertyString = propertyString .. "[FFFFFF]" .. spawnRegions[i] .. "\n"
            end
        end
        SetTooltipEntry(this,"megaSpawnerRegions",descriptionColor .. propertyString,950)
    end     
    if(this:HasObjVar("spawnTable")) then
        RemoveTooltipEntry(this,"megaSpawnerTable")
        local spawnList = StringSplit(this:GetObjVar("spawnTable"),",")
        local propertyString = "[FF7700]Possible Templates to Spawn\n"
        for i=1,#spawnList do
            if(i==#spawnList) then
                propertyString = propertyString .. "[FFFFFF]" .. spawnList[i]
            else
                propertyString = propertyString .. "[FFFFFF]" .. spawnList[i] .. "\n"
            end
        end

        SetTooltipEntry(this,"megaSpawnerTable",descriptionColor .. propertyString,940)
    end    
    if(this:HasObjVar("spawnData")) then
        RemoveTooltipEntry(this,"megaSpawnerSpawnData")
        local spawnData = this:GetObjVar("spawnData")
        local propertyString = "[FF7700]Current Spawned Templates\n"
        for k,v in pairs(spawnData) do
            if(v.ObjRef) then
                if(v.ObjRef:IsValid()) then
                    if(k==#spawnData) then
                        propertyString = propertyString .. "[FFFFFF]" .. v.ObjRef:GetCreationTemplateId()
                    else
                        propertyString = propertyString .. "[FFFFFF]" .. v.ObjRef:GetCreationTemplateId() .. "\n"
                    end
                end
            end
        end        
        SetTooltipEntry(this,"megaSpawnerSpawnData",descriptionColor .. propertyString,930)
    end              
end

-- this allows the function to be overridden in a mod
RegisterEventHandler(EventType.CreatedObject, "mobSpawned", function(...) MobSpawned(...) end)

RegisterEventHandler(EventType.Timer, "spawnTimer", 
	function()
		CheckSpawn()
	end)
RegisterEventHandler(EventType.Message,"Activate",function ( ... )
    this:DelObjVar("Disable")
end)
RegisterEventHandler(EventType.Message,"Deactivate",function ( ... )
    this:SetObjVar("Disable",true)
end)
RegisterEventHandler(EventType.Message,"RemoveSpawnedObject",function (targetObj)
    local spawnData = this:GetObjVar("spawnData")

    for i,spawnInfo in pairs(spawnData) do
        if(spawnInfo.ObjRef == targetObj) then
            spawnInfo.ObjRef = nil
            spawnInfo.GoneTime = DateTime.UtcNow
        end
    end
    this:SetObjVar("spawnData",spawnData)
end)

RegisterSingleEventHandler(EventType.ModuleAttached, "mega_spawner", 
    function()

        CheckSpawn()
        
    end)

RegisterEventHandler(EventType.Message, "UseObject", function(user,usedType)
    ShowSpawnerUserInterface(user)
end)

this:ScheduleTimerDelay(GetSpawnPulse(), "spawnTimer")