-- A SALVAGED ITEM MUST HAVE 2 TABLE ENTRIES
-- EquipmentStats.BaseWeaponStats key and add a key to that table named "SalvageResource"
-- ResourceData.ResourceInfo key, this is for referencing that tables key named Template

MobileEffectLibrary.Salvaging = 
{
	OnEnterState = function(self,root,target,args)
		self.RequestInitialTarget(self,root,target,args)			
	end,
	RequestInitialTarget = function(self,root,target,args)
		RegisterSingleEventHandler(EventType.ClientTargetGameObjResponse, "SalvagingMobileEffectTarget", function (targetObj,user)
			if ( targetObj ) then
				self.ProcessSalvage(self,root,targetObj)				
			else
				EndMobileEffect(root)
			end
		end)
		RegisterSingleEventHandler(EventType.CreatedObject, "CreateSalvagedItem", function (success,objRef,amount)
			if(objRef:HasModule("stackable")) then
				self.ParentObj:SystemMessage("Yup")
				local stackCount = objRef:GetObjVar("StackCount") or 1
				stackCount = stackCount + amount
				objRef:SetObjVar("StackCount",stackCount)
				TryStack(objRef, self.ParentObj:GetEquippedObject("Backpack"), false, true)
				self.ParentObj:SystemMessage("you salvaged " .. amount .. " " .. objRef:GetName(),"event")
			end
		end)		
		self.ParentObj:RequestClientTargetGameObj(self.ParentObj, "SalvagingMobileEffectTarget")
	end,
	DetermineResourceAmount = function(self,root,target)
		local amountToGive = 1
		local craftSkillValue = 0
		local propertyBonus = 0
		if(AllRecipes.MetalsmithSkill[target:GetObjVar("WeaponType")] or AllRecipes.MetalsmithSkill[target:GetObjVar("ArmorType")] or AllRecipes.MetalsmithSkill["ShieldType"] or AllRecipes.MetalsmithSkill["JewelryType"]) then
			craftSkillValue = GetSkillLevel(self.ParentObj,"MetalsmithSkill")
		elseif(AllRecipes.WoodsmithSkill[target:GetObjVar("WeaponType")] or AllRecipes.WoodsmithSkill["ShieldType"]) then
			craftSkillValue = GetSkillLevel(self.ParentObj,"WoodsmithSkill")		
		elseif(AllRecipes.FabricationSkill[target:GetObjVar("ArmorType")])then
			craftSkillValue = GetSkillLevel(self.ParentObj,"FabricationSkill")				
		end
		if(craftSkillValue >= 100) then amountToGive = amountToGive + 1	end
		if(self.ParentObj:IsPlayer()) then
	        propertyBonus = GetCachedMobileModByName("SkillBonusSalvaging",self.ParentObj) or 0
	    end			
		return math.random(1 + propertyBonus, amountToGive + propertyBonus)
	end,
	ProcessSalvage = function(self,root,target)	
		if(IsInBackpack(target,self.ParentObj)) then
			local equipmentType = target:GetObjVar("WeaponType") or target:GetObjVar("ArmorType") or target:GetObjVar("ShieldType") or target:GetObjVar("JewelryType") or nil
			if(equipmentType) then
				local resourceGiven = "NONE"
				if (target:HasObjVar("WeaponType")) then resourceGiven = EquipmentStats.BaseWeaponStats[equipmentType].SalvageResource end
				if (target:HasObjVar("ArmorType")) then resourceGiven = EquipmentStats.BaseArmorStats[equipmentType].SalvageResource end
				if (target:HasObjVar("ShieldType")) then resourceGiven = EquipmentStats.BaseShieldStats[equipmentType].SalvageResource end
				if (target:HasObjVar("JewelryType")) then resourceGiven = "Iron" end
				local createTemplate = ResourceData.ResourceInfo[resourceGiven].Template
				-- update create method so resources stack in the backpack
				CheckSkillChance(self.ParentObj, "SalvagingSkill", GetSkillLevel(self.ParentObj,"SalvagingSkill"),SkillValueMinMax(GetSkillLevel(self.ParentObj,"SalvagingSkill"), 0, 100))		
				local amountOfResources = self.DetermineResourceAmount(self,root,target)
				CreateObjInBackpackOrAtLocation(self.ParentObj, createTemplate, "CreateSalvagedItem",amountOfResources)				
				target:Destroy()
			else
				self.ParentObj:SystemMessage("this item can not be salvaged")
			end
		else
			self.ParentObj:SystemMessage("this item must be in your backpack to salvage")
		end
		--when done end it
		EndMobileEffect(root)
	end,
}